package com.gic.haoban.manage.service.service.notify.out;

import com.gic.api.base.commons.BasePageInfo;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.PageHelperUtils;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.manage.api.dto.notify.dto.PendingTaskDTO;
import com.gic.haoban.manage.api.dto.notify.dto.PendingTaskDetailDTO;
import com.gic.haoban.manage.api.dto.notify.qdto.PendingListQDTO;
import com.gic.haoban.manage.api.dto.notify.qdto.PendingTaskQDTO;
import com.gic.haoban.manage.api.enums.PendingTaskTypeEnum;
import com.gic.haoban.manage.api.service.notify.PendingTaskApiService;
import com.gic.haoban.manage.service.pojo.BO.PendingTaskBO;
import com.gic.haoban.manage.service.service.notify.PendingTaskService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * Created 2021/12/16.
 *
 * @author hua
 */
@Service
public class PendingTaskApiServiceImpl implements PendingTaskApiService {

    @Autowired
    private PendingTaskService pendingTaskService;

    @Override
    public void addPendingTask(PendingTaskQDTO qdto) {
        //新增待办
        pendingTaskService.addOrUpdatePendingTask(EntityUtil.changeEntityByOrika(PendingTaskBO.class, qdto));
    }


    @Override
    public ServiceResponse<Page<PendingTaskDetailDTO>> pagePendingTask(PendingListQDTO listQDTO, BasePageInfo pageInfo) {
        Page<PendingTaskBO> pendingTask = pendingTaskService.pagePendingTask(listQDTO.getEnterpriseId(), listQDTO.getStoreId(), listQDTO.getClerkId(), listQDTO.getFinishFlag()
                , listQDTO.getOverdueFlag(), pageInfo);
        //转化
        Page<PendingTaskDetailDTO> retPage = PageHelperUtils.changePageToCurrentPage(pendingTask, PendingTaskDetailDTO.class);
        if (CollectionUtils.isEmpty(retPage.getResult())) {
            return ServiceResponse.success(retPage);
        }
        retPage.getResult().forEach(dto -> {
            String title = dto.getTitle();
            PendingTaskTypeEnum taskTypeEnum = PendingTaskTypeEnum.getByType(dto.getTaskType());
            dto.setDescription(taskTypeEnum.getDescription().replace("{}", title));
            dto.setTitle(taskTypeEnum.getName());
        });
        return ServiceResponse.success(retPage);
    }

    @Override
    public ServiceResponse<List<PendingTaskDetailDTO>> listPendingTaskToday(String enterpriseId, String storeId, String clerkId, boolean seeSelf) {
        String yyyyMMdd = DateFormatUtils.format(new Date(), "yyyy-MM-dd");
        String startDate = yyyyMMdd + " 00:00:00";
        String endDate = yyyyMMdd + " 23:59:59";
        List<PendingTaskBO> todayPending = pendingTaskService.listPendingTaskByCreateTime(enterpriseId, storeId, clerkId, startDate, endDate);
        List<PendingTaskDetailDTO> retList = EntityUtil.changeEntityListByJSON(PendingTaskDetailDTO.class, todayPending);
        if (CollectionUtils.isEmpty(retList)) {
            return ServiceResponse.success(retList);
        }
        retList.forEach(dto -> {
            String title = dto.getTitle();
            PendingTaskTypeEnum taskTypeEnum = PendingTaskTypeEnum.getByType(dto.getTaskType());
            dto.setDescription(taskTypeEnum.getDescription().replace("{}", title));
            dto.setTitle(taskTypeEnum.getName());
        });
        return ServiceResponse.success(retList);
    }
}
